Crate cognee_embedding

Crate cognee_embedding 

Multi-provider text-embedding engine (ONNX, OpenAI-compatible, Ollama, Mock).

Re-exports

pub use config::EmbeddingConfig;
pub use engine::EmbeddingEngine;
pub use error::EmbeddingError;
pub use error::EmbeddingResult;
pub use mock::MockEmbeddingEngine;
pub use mock::MockVectorMode;
pub use ollama::OllamaEmbeddingEngine;
pub use openai_compatible::OpenAICompatibleEmbeddingEngine;
pub use provider::EmbeddingProvider;
pub use utils::handle_embedding_response;
pub use utils::is_embeddable;
pub use utils::sanitize_embedding_inputs;
pub use config::OnnxEmbeddingConfig;
pub use download::ModelUrls;
pub use download::download_model;
pub use download::ensure_model_exists;
pub use download::ensure_tokenizer_exists;
pub use onnx::OnnxEmbeddingEngine;

Modules

config
Embedding engine configuration.
download
Lazy model and tokenizer download from HuggingFace Hub. Lazy downloading of embedding models and tokenizers from HuggingFace Hub.
engine
EmbeddingEngine trait definition.
error
Error types for embedding operations.
mock
Mock embedding engine for tests.
ollama
Ollama embedding engine implementation. Ollama embedding engine.
onnx
ONNX Runtime-based local embedding engine.
openai_compatible
OpenAI-compatible embedding engine implementation. OpenAI-compatible embedding engine.
provider
Embedding provider selection.
utils
Shared utilities for embedding input sanitization and response handling.